@@ -20,8 +20,6 @@
   ==============================================================================
 */
 
-#include <juce_audio_basics/native/juce_CoreAudioTimeConversions_mac.h>
-
 namespace juce
 {
 
@@ -195,10 +193,6 @@ JUCE_END_IGNORE_WARNINGS_GCC_LIKE
 @end
 
 //==============================================================================
-#if JUCE_MODULE_AVAILABLE_juce_graphics
- #include <juce_graphics/native/juce_CoreGraphicsHelpers_mac.h>
-#endif
-
 namespace juce {
 
 #ifndef JUCE_IOS_AUDIO_LOGGING
@@ -223,8 +217,8 @@ static void logNSError (NSError* e)
 #define JUCE_NSERROR_CHECK(X)     { NSError* error = nil; X; logNSError (error); }
 
 //==============================================================================
-class iOSAudioIODeviceType  : public AudioIODeviceType,
-                              public AsyncUpdater
+class iOSAudioIODeviceType final : public AudioIODeviceType,
+                                   public AsyncUpdater
 {
 public:
     iOSAudioIODeviceType();
@@ -252,7 +246,7 @@ private:
 };
 
 //==============================================================================
-struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
+struct iOSAudioIODevice::Pimpl final : public AsyncUpdater
 {
     Pimpl (iOSAudioIODeviceType* ioDeviceType, iOSAudioIODevice& ioDevice)
         : deviceType (ioDeviceType),
@@ -282,7 +276,7 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
 
     static void setAudioSessionCategory (NSString* category)
     {
-        NSUInteger options = 0;
+        NSUInteger options = AVAudioSessionCategoryOptionAllowAirPlay;
 
        #if ! JUCE_DISABLE_AUDIO_MIXING_WITH_OTHER_APPS
         options |= AVAudioSessionCategoryOptionMixWithOthers; // Alternatively AVAudioSessionCategoryOptionDuckOthers
@@ -290,8 +284,8 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
 
         if (category == AVAudioSessionCategoryPlayAndRecord)
         {
-            options |= (AVAudioSessionCategoryOptionDefaultToSpeaker
-                      | AVAudioSessionCategoryOptionAllowBluetooth);
+            options |= AVAudioSessionCategoryOptionDefaultToSpeaker
+                     | AVAudioSessionCategoryOptionAllowBluetooth;
 
             if (@available (iOS 10.0, *))
                 options |= AVAudioSessionCategoryOptionAllowBluetoothA2DP;
@@ -563,7 +557,7 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
     }
 
     //==============================================================================
-    class PlayHead : public AudioPlayHead
+    class PlayHead final : public AudioPlayHead
     {
     public:
         explicit PlayHead (Pimpl& implIn) : impl (implIn) {}
@@ -640,18 +634,18 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
             Boolean hostIsCycling               = NO;
             Float64 hostCycleStartBeat          = 0;
             Float64 hostCycleEndBeat            = 0;
-            OSStatus err = callbackInfo.transportStateProc2 (callbackInfo.hostUserData,
-                                                             &hostIsPlaying,
-                                                             &hostIsRecording,
-                                                             nullptr,
-                                                             &hostCurrentSampleInTimeLine,
-                                                             &hostIsCycling,
-                                                             &hostCycleStartBeat,
-                                                             &hostCycleEndBeat);
-            if (err == kAUGraphErr_CannotDoInCurrentContext)
+            auto transportErr = callbackInfo.transportStateProc2 (callbackInfo.hostUserData,
+                                                                  &hostIsPlaying,
+                                                                  &hostIsRecording,
+                                                                  nullptr,
+                                                                  &hostCurrentSampleInTimeLine,
+                                                                  &hostIsCycling,
+                                                                  &hostCycleStartBeat,
+                                                                  &hostCycleEndBeat);
+            if (transportErr == kAUGraphErr_CannotDoInCurrentContext)
                 return {};
 
-            jassert (err == noErr);
+            jassert (transportErr == noErr);
 
             PositionInfo result;
 
@@ -660,14 +654,14 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
             result.setIsRecording   (hostIsRecording);
             result.setIsLooping     (hostIsCycling);
             result.setLoopPoints    (LoopPoints { hostCycleStartBeat, hostCycleEndBeat });
-            result.setTimeInSeconds (*result.getTimeInSamples() / impl.sampleRate);
+            result.setTimeInSeconds ((double) *result.getTimeInSamples() / impl.sampleRate);
 
             Float64 hostBeat = 0;
             Float64 hostTempo = 0;
-            err = callbackInfo.beatAndTempoProc (callbackInfo.hostUserData,
-                                                 &hostBeat,
-                                                 &hostTempo);
-            jassert (err == noErr);
+            [[maybe_unused]] auto batErr = callbackInfo.beatAndTempoProc (callbackInfo.hostUserData,
+                                                                          &hostBeat,
+                                                                          &hostTempo);
+            jassert (batErr == noErr);
 
             result.setPpqPosition (hostBeat);
             result.setBpm         (hostTempo);
@@ -675,12 +669,12 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
             Float32 hostTimeSigNumerator = 0;
             UInt32 hostTimeSigDenominator = 0;
             Float64 hostCurrentMeasureDownBeat = 0;
-            err = callbackInfo.musicalTimeLocationProc (callbackInfo.hostUserData,
-                                                        nullptr,
-                                                        &hostTimeSigNumerator,
-                                                        &hostTimeSigDenominator,
-                                                        &hostCurrentMeasureDownBeat);
-            jassert (err == noErr);
+            [[maybe_unused]] auto timeErr = callbackInfo.musicalTimeLocationProc (callbackInfo.hostUserData,
+                                                                                  nullptr,
+                                                                                  &hostTimeSigNumerator,
+                                                                                  &hostTimeSigDenominator,
+                                                                                  &hostCurrentMeasureDownBeat);
+            jassert (timeErr == noErr);
 
             result.setPpqPositionOfLastBarStart (hostCurrentMeasureDownBeat);
             result.setTimeSignature (TimeSignature { (int) hostTimeSigNumerator, (int) hostTimeSigDenominator });
@@ -707,7 +701,7 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
         {
             if (interAppAudioConnected)
             {
-                if (UIImage* hostUIImage = AudioOutputUnitGetHostIcon (audioUnit, size))
+                if (UIImage* hostUIImage = AudioOutputUnitGetHostIcon (audioUnit, (float) size))
                     return juce_createImageFromUIImage (hostUIImage);
             }
         }
@@ -724,12 +718,12 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
 
         CFURLRef hostUrl;
         UInt32 dataSize = sizeof (hostUrl);
-        OSStatus err = AudioUnitGetProperty(audioUnit,
-                                            kAudioUnitProperty_PeerURL,
-                                            kAudioUnitScope_Global,
-                                            0,
-                                            &hostUrl,
-                                            &dataSize);
+        OSStatus err = AudioUnitGetProperty (audioUnit,
+                                             kAudioUnitProperty_PeerURL,
+                                             kAudioUnitScope_Global,
+                                             0,
+                                             &hostUrl,
+                                             &dataSize);
         if (err == noErr)
         {
             if (@available (iOS 10.0, *))
@@ -787,9 +781,9 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
         switch (reason)
         {
         case AVAudioSessionRouteChangeReasonCategoryChange:
-        case AVAudioSessionRouteChangeReasonOverride:
         case AVAudioSessionRouteChangeReasonRouteConfigurationChange:
             break;
+        case AVAudioSessionRouteChangeReasonOverride:
         case AVAudioSessionRouteChangeReasonUnknown:
         case AVAudioSessionRouteChangeReasonNewDeviceAvailable:
         case AVAudioSessionRouteChangeReasonOldDeviceUnavailable:
@@ -991,7 +985,7 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
         appDesc.componentFlags = 0;
         appDesc.componentFlagsMask = 0;
         OSStatus err = AudioOutputUnitPublish (&appDesc,
-                                               CFSTR(JucePlugin_IAAName),
+                                               CFSTR (JucePlugin_IAAName),
                                                JucePlugin_VersionCode,
                                                audioUnit);
 
@@ -1065,6 +1059,19 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
             }
         }
 
+       #if JUCE_AUDIOWORKGROUP_TYPES_AVAILABLE
+        workgroup = [this]
+        {
+            UInt32 dataSize = sizeof (os_workgroup_t);
+            os_workgroup_t wgHandle = nullptr;
+
+            AudioUnitGetProperty (audioUnit, kAudioOutputUnitProperty_OSWorkgroup,
+                                  kAudioUnitScope_Global, 0, &wgHandle, &dataSize);
+
+            return makeRealAudioWorkgroup (wgHandle);
+        }();
+       #endif
+
         AudioUnitAddPropertyListener (audioUnit, kAudioUnitProperty_StreamFormat, dispatchAudioUnitPropertyChange, this);
 
         return true;
@@ -1373,6 +1380,7 @@ struct iOSAudioIODevice::Pimpl      : public AsyncUpdater
     Atomic<bool> hardwareInfoNeedsUpdating { true };
 
     AudioUnit audioUnit {};
+    AudioWorkgroup workgroup;
 
     SharedResourcePointer<AudioSessionHolder> sessionHolder;
 
@@ -1429,6 +1437,7 @@ BigInteger iOSAudioIODevice::getActiveOutputChannels() const        { return pim
 int iOSAudioIODevice::getInputLatencyInSamples()                    { return roundToInt (pimpl->sampleRate * [AVAudioSession sharedInstance].inputLatency); }
 int iOSAudioIODevice::getOutputLatencyInSamples()                   { return roundToInt (pimpl->sampleRate * [AVAudioSession sharedInstance].outputLatency); }
 int iOSAudioIODevice::getXRunCount() const noexcept                 { return pimpl->xrun; }
+AudioWorkgroup iOSAudioIODevice::getWorkgroup() const               { return pimpl->workgroup; }
 
 void iOSAudioIODevice::setMidiMessageCollector (MidiMessageCollector* collector) { pimpl->messageCollector = collector; }
 AudioPlayHead* iOSAudioIODevice::getAudioPlayHead() const           { return &pimpl->playhead; }
