@@ -146,6 +146,7 @@
 #include "misc/juce_Result.cpp"
 #include "misc/juce_Uuid.cpp"
 #include "misc/juce_ConsoleApplication.cpp"
+#include "misc/juce_ScopeGuard.cpp"
 #include "network/juce_MACAddress.cpp"
 #include "network/juce_NamedPipe.cpp"
 #include "network/juce_Socket.cpp"
@@ -177,6 +178,7 @@
 #include "unit_tests/juce_UnitTest.cpp"
 #include "containers/juce_Variant.cpp"
 #include "javascript/juce_JSON.cpp"
+#include "javascript/juce_JSONUtils.cpp"
 #include "javascript/juce_Javascript.cpp"
 #include "containers/juce_DynamicObject.cpp"
 #include "xml/juce_XmlDocument.cpp"
@@ -276,9 +278,14 @@
 //==============================================================================
 #if JUCE_UNIT_TESTS
  #include "containers/juce_HashMap_test.cpp"
-
  #include "containers/juce_Optional_test.cpp"
+ #include "maths/juce_MathsFunctions_test.cpp"
  #include "misc/juce_EnumHelpers_test.cpp"
+ #include "containers/juce_FixedSizeFunction_test.cpp"
+ #include "javascript/juce_JSONSerialisation_test.cpp"
+ #if JUCE_MAC || JUCE_IOS
+  #include "native/juce_ObjCHelpers_mac_test.mm"
+ #endif
 #endif
 
 //==============================================================================
