@@ -35,12 +35,12 @@
 
   ID:                 juce_dsp
   vendor:             juce
-  version:            7.0.0
+  version:            7.0.8
   name:               JUCE DSP classes
   description:        Classes for audio buffer manipulation, digital audio processing, filtering, oversampling, fast math functions etc.
   website:            http://www.juce.com/juce
   license:            GPL/Commercial
-  minimumCppStandard: 14
+  minimumCppStandard: 17
 
   dependencies:       juce_audio_formats
   OSXFrameworks:      Accelerate
@@ -58,9 +58,9 @@
 #include <juce_audio_basics/juce_audio_basics.h>
 #include <juce_audio_formats/juce_audio_formats.h>
 
-#if defined(_M_X64) || defined(__amd64__) || defined(__SSE2__) || (defined(_M_IX86_FP) && _M_IX86_FP == 2)
+#if defined (_M_X64) || defined (__amd64__) || defined (__SSE2__) || (defined (_M_IX86_FP) && _M_IX86_FP == 2)
 
- #if defined(_M_X64) || defined(__amd64__)
+ #if defined (_M_X64) || defined (__amd64__)
   #ifndef __SSE2__
    #define __SSE2__
   #endif
@@ -74,7 +74,9 @@
   #include <immintrin.h>
  #endif
 
-#elif defined (__ARM_NEON__) || defined (__ARM_NEON) || defined (__arm64__) || defined (__aarch64__)
+// it's ok to check for _M_ARM below as this is only defined on Windows for Arm 32-bit
+// which has a minimum requirement of armv7, which supports neon.
+#elif defined (__ARM_NEON__) || defined (__ARM_NEON) || defined (__arm64__) || defined (__aarch64__) || defined (_M_ARM) || defined (_M_ARM64)
 
  #ifndef JUCE_USE_SIMD
   #define JUCE_USE_SIMD 1
@@ -94,7 +96,7 @@
 #ifndef JUCE_VECTOR_CALLTYPE
  // __vectorcall does not work on 64-bit due to internal compiler error in
  // release mode VS2017. Re-enable when Microsoft fixes this
- #if _MSC_VER && JUCE_USE_SIMD && ! (defined(_M_X64) || defined(__amd64__))
+ #if _MSC_VER && JUCE_USE_SIMD && ! (defined (_M_X64) || defined (__amd64__))
   #define JUCE_VECTOR_CALLTYPE __vectorcall
  #else
   #define JUCE_VECTOR_CALLTYPE
@@ -186,54 +188,57 @@
 #undef Factor
 #undef check
 
-namespace juce
+namespace juce::dsp
 {
-    namespace dsp
-    {
-        template <typename Type>
-        using Complex = std::complex<Type>;
 
-        //==============================================================================
-        namespace util
-        {
-            /** Use this function to prevent denormals on intel CPUs.
-                This function will work with both primitives and simple containers.
-            */
-          #if JUCE_DSP_ENABLE_SNAP_TO_ZERO
-            inline void snapToZero (float&       x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
-           #ifndef DOXYGEN
-            inline void snapToZero (double&      x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
-            inline void snapToZero (long double& x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
-           #endif
-          #else
-            inline void snapToZero (float&       x) noexcept            { ignoreUnused (x); }
-           #ifndef DOXYGEN
-            inline void snapToZero (double&      x) noexcept            { ignoreUnused (x); }
-            inline void snapToZero (long double& x) noexcept            { ignoreUnused (x); }
-           #endif
-          #endif
-        }
-    }
+template <typename Type>
+using Complex = std::complex<Type>;
+
+template <size_t len, typename T>
+using FixedSizeFunction = juce::FixedSizeFunction<len, T>;
+
+//==============================================================================
+namespace util
+{
+    /** Use this function to prevent denormals on intel CPUs.
+        This function will work with both primitives and simple containers.
+    */
+  #if JUCE_DSP_ENABLE_SNAP_TO_ZERO
+    inline void snapToZero (float&       x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
+   #ifndef DOXYGEN
+    inline void snapToZero (double&      x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
+    inline void snapToZero (long double& x) noexcept            { JUCE_SNAP_TO_ZERO (x); }
+   #endif
+  #else
+    inline void snapToZero ([[maybe_unused]] float&       x) noexcept            {}
+   #ifndef DOXYGEN
+    inline void snapToZero ([[maybe_unused]] double&      x) noexcept            {}
+    inline void snapToZero ([[maybe_unused]] long double& x) noexcept            {}
+   #endif
+  #endif
+}
+
 }
 
 //==============================================================================
 #if JUCE_USE_SIMD
- #include "native/juce_fallback_SIMDNativeOps.h"
+ #include "native/juce_SIMDNativeOps_fallback.h"
 
  // include the correct native file for this build target CPU
- #if defined(__i386__) || defined(__amd64__) || defined(_M_X64) || defined(_X86_) || defined(_M_IX86)
+ #if defined (__i386__) || defined (__amd64__) || defined (_M_X64) || defined (_X86_) || defined (_M_IX86)
   #ifdef __AVX2__
-   #include "native/juce_avx_SIMDNativeOps.h"
+   #include "native/juce_SIMDNativeOps_avx.h"
   #else
-   #include "native/juce_sse_SIMDNativeOps.h"
+   #include "native/juce_SIMDNativeOps_sse.h"
   #endif
- #elif defined(__arm__) || defined(_M_ARM) || defined (__arm64__) || defined (__aarch64__)
-  #include "native/juce_neon_SIMDNativeOps.h"
+ #elif JUCE_ARM
+  #include "native/juce_SIMDNativeOps_neon.h"
  #else
   #error "SIMD register support not implemented for this platform"
  #endif
 
  #include "containers/juce_SIMDRegister.h"
+ #include "containers/juce_SIMDRegister_Impl.h"
 #endif
 
 #include "maths/juce_SpecialFunctions.h"
@@ -244,12 +249,12 @@ namespace juce
 #include "maths/juce_LookupTable.h"
 #include "maths/juce_LogRampedValue.h"
 #include "containers/juce_AudioBlock.h"
-#include "containers/juce_FixedSizeFunction.h"
 #include "processors/juce_ProcessContext.h"
 #include "processors/juce_ProcessorWrapper.h"
 #include "processors/juce_ProcessorChain.h"
 #include "processors/juce_ProcessorDuplicator.h"
 #include "processors/juce_IIRFilter.h"
+#include "processors/juce_IIRFilter_Impl.h"
 #include "processors/juce_FIRFilter.h"
 #include "processors/juce_StateVariableFilter.h"
 #include "processors/juce_FirstOrderTPTFilter.h"
