@@ -35,12 +35,12 @@
 
   ID:                 juce_gui_basics
   vendor:             juce
-  version:            7.0.2
+  version:            7.0.8
   name:               JUCE GUI core classes
   description:        Basic user-interface components and related classes.
   website:            http://www.juce.com/juce
   license:            GPL/Commercial
-  minimumCppStandard: 14
+  minimumCppStandard: 17
 
   dependencies:       juce_graphics juce_data_structures
   OSXFrameworks:      Cocoa QuartzCore
@@ -127,7 +127,6 @@ namespace juce
     class Component;
     class LookAndFeel;
     class MouseInputSource;
-    class MouseInputSourceInternal;
     class ComponentPeer;
     class MouseEvent;
     struct MouseWheelDetails;
@@ -161,16 +160,27 @@ namespace juce
     class Displays;
     class AccessibilityHandler;
     class KeyboardFocusTraverser;
-    class PointerState;
 
     class FlexBox;
     class Grid;
     class FocusOutline;
 
-   #if JUCE_MAC || JUCE_WINDOWS || JUCE_LINUX
+   #if JUCE_MAC || JUCE_WINDOWS || JUCE_LINUX || JUCE_BSD
     Image createSnapshotOfNativeWindow (void* nativeWindowHandle);
    #endif
-}
+
+    namespace detail
+    {
+        struct ComponentHelpers;
+        class MouseInputSourceImpl;
+        class MouseInputSourceList;
+        class PointerState;
+        class ScopedMessageBoxImpl;
+        class ToolbarItemDragAndDropOverlayComponent;
+        class TopLevelWindowManager;
+    } // namespace detail
+
+} // namespace juce
 
 #include "mouse/juce_MouseCursor.h"
 #include "mouse/juce_MouseListener.h"
@@ -189,6 +199,7 @@ namespace juce
 #include "desktop/juce_Desktop.h"
 #include "desktop/juce_Displays.h"
 #include "layout/juce_ComponentBoundsConstrainer.h"
+#include "layout/juce_BorderedComponentBoundsConstrainer.h"
 #include "mouse/juce_ComponentDragger.h"
 #include "mouse/juce_DragAndDropTarget.h"
 #include "mouse/juce_DragAndDropContainer.h"
@@ -269,6 +280,7 @@ namespace juce
 #include "widgets/juce_TreeView.h"
 #include "windows/juce_TopLevelWindow.h"
 #include "windows/juce_MessageBoxOptions.h"
+#include "windows/juce_ScopedMessageBox.h"
 #include "windows/juce_AlertWindow.h"
 #include "windows/juce_CallOutBox.h"
 #include "windows/juce_ComponentPeer.h"
@@ -278,6 +290,8 @@ namespace juce
 #include "windows/juce_NativeMessageBox.h"
 #include "windows/juce_ThreadWithProgressWindow.h"
 #include "windows/juce_TooltipWindow.h"
+#include "windows/juce_VBlankAttachment.h"
+#include "windows/juce_WindowUtils.h"
 #include "layout/juce_MultiDocumentPanel.h"
 #include "layout/juce_SidePanel.h"
 #include "filebrowser/juce_FileBrowserListener.h"
@@ -322,7 +336,9 @@ namespace juce
 #if JUCE_LINUX || JUCE_BSD
  #if JUCE_GUI_BASICS_INCLUDE_XHEADERS
   // If you're missing these headers, you need to install the libx11-dev package
+  JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wvariadic-macros")
   #include <X11/Xlib.h>
+  JUCE_END_IGNORE_WARNINGS_GCC_LIKE
   #include <X11/Xatom.h>
   #include <X11/Xresource.h>
   #include <X11/Xutil.h>
@@ -362,13 +378,13 @@ namespace juce
   #undef SIZEOF
   #undef KeyPress
 
-  #include "native/x11/juce_linux_XWindowSystem.h"
-  #include "native/x11/juce_linux_X11_Symbols.h"
+  #include "native/juce_XWindowSystem_linux.h"
+  #include "native/juce_XSymbols_linux.h"
  #endif
 #endif
 
 #if JUCE_GUI_BASICS_INCLUDE_SCOPED_THREAD_DPI_AWARENESS_SETTER && JUCE_WINDOWS
- #include "native/juce_win32_ScopedThreadDPIAwarenessSetter.h"
+ #include "native/juce_ScopedThreadDPIAwarenessSetter_windows.h"
 #endif
 
 #include "layout/juce_FlexItem.h"
