@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -41,11 +41,23 @@ struct PopupMenu::HelperClasses
 class MouseSourceState;
 struct MenuWindow;
 
-static bool canBeTriggered (const PopupMenu::Item& item) noexcept        { return item.isEnabled && item.itemID != 0 && ! item.isSectionHeader; }
-static bool hasActiveSubMenu (const PopupMenu::Item& item) noexcept      { return item.isEnabled && item.subMenu != nullptr && item.subMenu->items.size() > 0; }
+static bool canBeTriggered (const PopupMenu::Item& item) noexcept
+{
+    return item.isEnabled
+        && item.itemID != 0
+        && ! item.isSectionHeader
+        && (item.customComponent == nullptr || item.customComponent->isTriggeredAutomatically());
+}
+
+static bool hasActiveSubMenu (const PopupMenu::Item& item) noexcept
+{
+    return item.isEnabled
+        && item.subMenu != nullptr
+        && item.subMenu->items.size() > 0;
+}
 
 //==============================================================================
-struct HeaderItemComponent  : public PopupMenu::CustomComponent
+struct HeaderItemComponent final : public PopupMenu::CustomComponent
 {
     HeaderItemComponent (const String& name, const Options& opts)
         : CustomComponent (false), options (opts)
@@ -73,17 +85,20 @@ struct HeaderItemComponent  : public PopupMenu::CustomComponent
         idealWidth += idealWidth / 4;
     }
 
+    std::unique_ptr<AccessibilityHandler> createAccessibilityHandler() override
+    {
+        return createIgnoredAccessibilityHandler (*this);
+    }
+
     const Options& options;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (HeaderItemComponent)
 };
 
 //==============================================================================
-struct ItemComponent  : public Component
+struct ItemComponent final : public Component
 {
-    ItemComponent (const PopupMenu::Item& i,
-                   const PopupMenu::Options& o,
-                   MenuWindow& parent)
+    ItemComponent (const PopupMenu::Item& i, const PopupMenu::Options& o, MenuWindow& parent)
         : item (i), parentWindow (parent), options (o), customComp (i.customComponent)
     {
         if (item.isSectionHeader)
@@ -164,16 +179,22 @@ struct ItemComponent  : public Component
         }
     }
 
+    static bool isAccessibilityHandlerRequired (const PopupMenu::Item& item)
+    {
+        return item.isSectionHeader || hasActiveSubMenu (item) || canBeTriggered (item);
+    }
+
     PopupMenu::Item item;
 
 private:
     //==============================================================================
-    class ItemAccessibilityHandler  : public AccessibilityHandler
+    class ItemAccessibilityHandler final : public AccessibilityHandler
     {
     public:
         explicit ItemAccessibilityHandler (ItemComponent& itemComponentToWrap)
             : AccessibilityHandler (itemComponentToWrap,
-                                    AccessibilityRole::menuItem,
+                                    isAccessibilityHandlerRequired (itemComponentToWrap.item) ? AccessibilityRole::menuItem
+                                                                                              : AccessibilityRole::ignored,
                                     getAccessibilityActions (*this, itemComponentToWrap)),
               itemComponent (itemComponentToWrap)
         {
@@ -195,6 +216,9 @@ private:
                                                                       : state.withExpandable().withCollapsed();
             }
 
+            if (itemComponent.item.isTicked)
+                state = state.withCheckable().withChecked();
+
             return state.isFocused() ? state.withSelected() : state;
         }
 
@@ -209,12 +233,6 @@ private:
                 item.parentWindow.setCurrentlyHighlightedChild (&item);
             };
 
-            auto onPress = [&item]
-            {
-                item.parentWindow.setCurrentlyHighlightedChild (&item);
-                item.parentWindow.triggerCurrentlyHighlightedItem();
-            };
-
             auto onToggle = [&handler, &item, onFocus]
             {
                 if (handler.getCurrentState().isSelected())
@@ -224,9 +242,17 @@ private:
             };
 
             auto actions = AccessibilityActions().addAction (AccessibilityActionType::focus,  std::move (onFocus))
-                                                 .addAction (AccessibilityActionType::press,  std::move (onPress))
                                                  .addAction (AccessibilityActionType::toggle, std::move (onToggle));
 
+            if (canBeTriggered (item.item))
+            {
+                actions.addAction (AccessibilityActionType::press, [&item]
+                {
+                    item.parentWindow.setCurrentlyHighlightedChild (&item);
+                    item.parentWindow.triggerCurrentlyHighlightedItem();
+                });
+            }
+
             if (hasActiveSubMenu (item.item))
             {
                 auto showSubMenu = [&item]
@@ -249,7 +275,8 @@ private:
 
     std::unique_ptr<AccessibilityHandler> createAccessibilityHandler() override
     {
-        return item.isSeparator ? nullptr : std::make_unique<ItemAccessibilityHandler> (*this);
+        return item.isSeparator ? createIgnoredAccessibilityHandler (*this)
+                                : std::make_unique<ItemAccessibilityHandler> (*this);
     }
 
     //==============================================================================
@@ -295,38 +322,38 @@ private:
 };
 
 //==============================================================================
-struct MenuWindow  : public Component
+struct MenuWindow final : public Component
 {
-    MenuWindow (const PopupMenu& menu, MenuWindow* parentWindow,
-                Options opts, bool alignToRectangle, bool shouldDismissOnMouseUp,
-                ApplicationCommandManager** manager, float parentScaleFactor = 1.0f)
-       : Component ("menu"),
-         parent (parentWindow),
-         options (std::move (opts)),
-         managerOfChosenCommand (manager),
-         componentAttachedTo (options.getTargetComponent()),
-         dismissOnMouseUp (shouldDismissOnMouseUp),
-         windowCreationTime (Time::getMillisecondCounter()),
-         lastFocusedTime (windowCreationTime),
-         timeEnteredCurrentChildComp (windowCreationTime),
-         scaleFactor (parentWindow != nullptr ? parentScaleFactor : 1.0f)
+    MenuWindow (const PopupMenu& menu,
+                MenuWindow* parentWindow,
+                Options opts,
+                bool alignToRectangle,
+                bool shouldDismissOnMouseUp,
+                ApplicationCommandManager** manager,
+                float parentScaleFactor = 1.0f)
+        : Component ("menu"),
+          parent (parentWindow),
+          options (opts.withParentComponent (findNonNullLookAndFeel (menu, parentWindow).getParentComponentForMenuOptions (opts))),
+          managerOfChosenCommand (manager),
+          componentAttachedTo (options.getTargetComponent()),
+          dismissOnMouseUp (shouldDismissOnMouseUp),
+          windowCreationTime (Time::getMillisecondCounter()),
+          lastFocusedTime (windowCreationTime),
+          timeEnteredCurrentChildComp (windowCreationTime),
+          scaleFactor (parentWindow != nullptr ? parentScaleFactor : 1.0f)
     {
         setWantsKeyboardFocus (false);
         setMouseClickGrabsKeyboardFocus (false);
         setAlwaysOnTop (true);
         setFocusContainerType (FocusContainerType::focusContainer);
 
-        setLookAndFeel (parent != nullptr ? &(parent->getLookAndFeel())
-                                          : menu.lookAndFeel.get());
+        setLookAndFeel (findLookAndFeel (menu, parentWindow));
 
         auto& lf = getLookAndFeel();
 
-        parentComponent = lf.getParentComponentForMenuOptions (options);
-        const_cast<Options&>(options) = options.withParentComponent (parentComponent);
-
-        if (parentComponent != nullptr)
+        if (auto* pc = options.getParentComponent())
         {
-            parentComponent->addChildComponent (this);
+            pc->addChildComponent (this);
         }
         else
         {
@@ -348,7 +375,7 @@ struct MenuWindow  : public Component
             Desktop::getInstance().addGlobalMouseListener (this);
         }
 
-        if (parentComponent == nullptr && parentWindow == nullptr && lf.shouldPopupMenuScaleWithTargetComponent (options))
+        if (options.getParentComponent() == nullptr && parentWindow == nullptr && lf.shouldPopupMenuScaleWithTargetComponent (options))
             if (auto* targetComponent = options.getTargetComponent())
                 scaleFactor = Component::getApproximateScaleFactorForComponent (targetComponent);
 
@@ -364,6 +391,7 @@ struct MenuWindow  : public Component
             if (i + 1 < menu.items.size() || ! item.isSeparator)
             {
                 auto* child = items.add (new ItemComponent (item, options, *this));
+                child->setExplicitFocusOrder (1 + i);
 
                 if (initialSelectedId != 0 && item.itemID == initialSelectedId)
                     setCurrentlyHighlightedChild (child);
@@ -374,7 +402,6 @@ struct MenuWindow  : public Component
 
         calculateWindowPos (targetArea, alignToRectangle);
         setTopLeftPosition (windowPos.getPosition());
-        updateYPositions();
 
         if (auto visibleID = options.getItemThatMustBeVisible())
         {
@@ -382,8 +409,13 @@ struct MenuWindow  : public Component
             {
                 if (item->item.itemID == visibleID)
                 {
-                    auto targetPosition = parentComponent != nullptr ? parentComponent->getLocalPoint (nullptr, targetArea.getTopLeft())
-                                                                     : targetArea.getTopLeft();
+                    const auto targetPosition = [&]
+                    {
+                        if (auto* pc = options.getParentComponent())
+                            return pc->getLocalPoint (nullptr, targetArea.getTopLeft());
+
+                        return targetArea.getTopLeft();
+                    }();
 
                     auto y = targetPosition.getY() - windowPos.getY();
                     ensureItemComponentIsVisible (*item, isPositiveAndBelow (y, windowPos.getHeight()) ? y : -1);
@@ -441,7 +473,7 @@ struct MenuWindow  : public Component
     {
         auto& lf = getLookAndFeel();
 
-        if (parentComponent != nullptr)
+        if (options.getParentComponent())
             lf.drawResizableFrame (g, getWidth(), getHeight(),
                                    BorderSize<int> (getLookAndFeel().getPopupMenuBorderSizeWithOptions (options)));
 
@@ -490,8 +522,13 @@ struct MenuWindow  : public Component
 
             exitModalState (resultID);
 
-            if (makeInvisible && deletionChecker != nullptr)
-                setVisible (false);
+            if (deletionChecker != nullptr)
+            {
+                exitingModalState = true;
+
+                if (makeInvisible)
+                    setVisible (false);
+            }
 
             if (resultID != 0
                  && item != nullptr
@@ -687,6 +724,9 @@ struct MenuWindow  : public Component
             if (! treeContains (currentlyModalWindow))
                 return false;
 
+        if (exitingModalState)
+            return false;
+
         return true;
     }
 
@@ -757,7 +797,7 @@ struct MenuWindow  : public Component
 
     bool doesAnyJuceCompHaveFocus()
     {
-        if (! isForegroundOrEmbeddedProcess (componentAttachedTo))
+        if (! detail::WindowingHelpers::isForegroundOrEmbeddedProcess (componentAttachedTo))
             return false;
 
         if (Component::getCurrentlyFocusedComponent() != nullptr)
@@ -781,28 +821,26 @@ struct MenuWindow  : public Component
         if (relativeTo != nullptr)
             targetPoint = relativeTo->localPointToGlobal (targetPoint);
 
-        auto parentArea = Desktop::getInstance().getDisplays().getDisplayForPoint (targetPoint * scaleFactor)
-                              #if JUCE_MAC || JUCE_ANDROID
-                               ->userArea;
-                              #else
-                               ->totalArea; // on windows, don't stop the menu overlapping the taskbar
-                              #endif
+        auto* display = Desktop::getInstance().getDisplays().getDisplayForPoint (targetPoint * scaleFactor);
+        auto parentArea = display->safeAreaInsets.subtractedFrom (display->totalArea);
 
-        if (parentComponent == nullptr)
-            return parentArea;
+        if (auto* pc = options.getParentComponent())
+        {
+            return pc->getLocalArea (nullptr,
+                                     pc->getScreenBounds()
+                                           .reduced (getLookAndFeel().getPopupMenuBorderSizeWithOptions (options))
+                                           .getIntersection (parentArea));
+        }
 
-        return parentComponent->getLocalArea (nullptr,
-                                              parentComponent->getScreenBounds()
-                                                    .reduced (getLookAndFeel().getPopupMenuBorderSizeWithOptions (options))
-                                                    .getIntersection (parentArea));
+        return parentArea;
     }
 
     void calculateWindowPos (Rectangle<int> target, const bool alignToRectangle)
     {
         auto parentArea = getParentArea (target.getCentre()) / scaleFactor;
 
-        if (parentComponent != nullptr)
-            target = parentComponent->getLocalArea (nullptr, target).getIntersection (parentArea);
+        if (auto* pc = options.getParentComponent())
+            target = pc->getLocalArea (nullptr, target).getIntersection (parentArea);
 
         auto maxMenuHeight = parentArea.getHeight() - 24;
 
@@ -1032,7 +1070,7 @@ struct MenuWindow  : public Component
                                             windowPos.getHeight() - (PopupMenuSettings::scrollZone + itemComp.getHeight())),
                                       currentY);
 
-                auto parentArea = getParentArea (windowPos.getPosition(), parentComponent) / scaleFactor;
+                auto parentArea = getParentArea (windowPos.getPosition(), options.getParentComponent()) / scaleFactor;
                 auto deltaY = wantedY - currentY;
 
                 windowPos.setSize (jmin (windowPos.getWidth(), parentArea.getWidth()),
@@ -1163,8 +1201,7 @@ struct MenuWindow  : public Component
             activeSubMenu.reset (new HelperClasses::MenuWindow (*(childComp->item.subMenu), this,
                                                                 options.withTargetScreenArea (childComp->getScreenBounds())
                                                                        .withMinimumWidth (0)
-                                                                       .withTargetComponent (nullptr)
-                                                                       .withParentComponent (parentComponent),
+                                                                       .withTargetComponent (nullptr),
                                                                 false, dismissOnMouseUp, managerOfChosenCommand, scaleFactor));
 
             activeSubMenu->setVisible (true); // (must be called before enterModalState on Windows to avoid DropShadower confusion)
@@ -1178,10 +1215,7 @@ struct MenuWindow  : public Component
 
     void triggerCurrentlyHighlightedItem()
     {
-        if (currentChild != nullptr
-             && canBeTriggered (currentChild->item)
-             && (currentChild->item.customComponent == nullptr
-                  || currentChild->item.customComponent->isTriggeredAutomatically()))
+        if (currentChild != nullptr && canBeTriggered (currentChild->item))
         {
             dismissMenu (&currentChild->item);
         }
@@ -1261,13 +1295,26 @@ struct MenuWindow  : public Component
                                                        }));
     }
 
+    LookAndFeel* findLookAndFeel (const PopupMenu& menu, MenuWindow* parentWindow) const
+    {
+        return parentWindow != nullptr ? &(parentWindow->getLookAndFeel())
+                                       : menu.lookAndFeel.get();
+    }
+
+    LookAndFeel& findNonNullLookAndFeel (const PopupMenu& menu, MenuWindow* parentWindow) const
+    {
+        if (auto* result = findLookAndFeel (menu, parentWindow))
+            return *result;
+
+        return getLookAndFeel();
+    }
+
     //==============================================================================
     MenuWindow* parent;
     const Options options;
     OwnedArray<ItemComponent> items;
     ApplicationCommandManager** managerOfChosenCommand;
     WeakReference<Component> componentAttachedTo;
-    Component* parentComponent = nullptr;
     Rectangle<int> windowPos;
     bool hasBeenOver = false, needsToScroll = false;
     bool dismissOnMouseUp, hideOnExit = false, disableMouseMoves = false, hasAnyJuceCompHadFocus = false;
@@ -1278,12 +1325,13 @@ struct MenuWindow  : public Component
     uint32 windowCreationTime, lastFocusedTime, timeEnteredCurrentChildComp;
     OwnedArray<MouseSourceState> mouseSourceStates;
     float scaleFactor;
+    bool exitingModalState = false;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (MenuWindow)
 };
 
 //==============================================================================
-class MouseSourceState  : public Timer
+class MouseSourceState final : public Timer
 {
 public:
     MouseSourceState (MenuWindow& w, MouseInputSource s)
@@ -1359,7 +1407,9 @@ private:
                     && (ModifierKeys::currentModifiers.isAnyMouseButtonDown()
                          || ComponentPeer::getCurrentModifiersRealtime().isAnyMouseButtonDown());
 
-        if (! window.doesAnyJuceCompHaveFocus())
+        const auto reallyContained = window.reallyContains (localMousePos, true);
+
+        if (! window.doesAnyJuceCompHaveFocus() && ! reallyContained)
         {
             if (timeNow > window.lastFocusedTime + 10)
             {
@@ -1368,10 +1418,9 @@ private:
                 // Note: This object may have been deleted by the previous call.
             }
         }
-        else if (wasDown && timeNow > window.windowCreationTime + 250
-                   && ! (isDown || overScrollArea))
+        else if (wasDown && timeNow > window.windowCreationTime + 250 && ! isDown && ! overScrollArea)
         {
-            if (window.reallyContains (localMousePos, true))
+            if (reallyContained)
                 window.triggerCurrentlyHighlightedItem();
             else if ((window.hasBeenOver || ! window.dismissOnMouseUp) && ! isOverAny)
                 window.dismissMenu (nullptr);
@@ -1525,7 +1574,7 @@ private:
 };
 
 //==============================================================================
-struct NormalComponentWrapper : public PopupMenu::CustomComponent
+struct NormalComponentWrapper final : public PopupMenu::CustomComponent
 {
     NormalComponentWrapper (Component& comp, int w, int h, bool triggerMenuItemAutomaticallyWhenClicked)
         : PopupMenu::CustomComponent (triggerMenuItemAutomaticallyWhenClicked),
@@ -1723,7 +1772,7 @@ PopupMenu::Item&& PopupMenu::Item::setImage (std::unique_ptr<Drawable> newImage)
 void PopupMenu::addItem (Item newItem)
 {
     // An ID of 0 is used as a return value to indicate that the user
-    // didn't pick anything, so you shouldn't use it as the ID for an item..
+    // didn't pick anything, so you shouldn't use it as the ID for an item.
     jassert (newItem.itemID != 0
               || newItem.isSeparator || newItem.isSectionHeader
               || newItem.subMenu != nullptr);
@@ -1831,12 +1880,23 @@ void PopupMenu::addColouredItem (int itemResultID, String itemText, Colour itemT
 
 void PopupMenu::addCustomItem (int itemResultID,
                                std::unique_ptr<CustomComponent> cc,
-                               std::unique_ptr<const PopupMenu> subMenu)
+                               std::unique_ptr<const PopupMenu> subMenu,
+                               const String& itemTitle)
 {
     Item i;
+    i.text = itemTitle;
     i.itemID = itemResultID;
     i.customComponent = cc.release();
     i.subMenu.reset (createCopyIfNotNull (subMenu.get()));
+
+    // If this assertion is hit, this item will be visible to screen readers but with
+    // no name, which may be confusing to users.
+    // It's probably a good idea to add a title for this menu item that describes
+    // the meaning of the item, or the contents of the submenu, as appropriate.
+    // If you don't want this menu item to be press-able directly, pass "false" to the
+    // constructor of the CustomComponent.
+    jassert (! (HelperClasses::ItemComponent::isAccessibilityHandlerRequired (i) && itemTitle.isEmpty()));
+
     addItem (std::move (i));
 }
 
@@ -1844,11 +1904,12 @@ void PopupMenu::addCustomItem (int itemResultID,
                                Component& customComponent,
                                int idealWidth, int idealHeight,
                                bool triggerMenuItemAutomaticallyWhenClicked,
-                               std::unique_ptr<const PopupMenu> subMenu)
+                               std::unique_ptr<const PopupMenu> subMenu,
+                               const String& itemTitle)
 {
     auto comp = std::make_unique<HelperClasses::NormalComponentWrapper> (customComponent, idealWidth, idealHeight,
                                                                          triggerMenuItemAutomaticallyWhenClicked);
-    addCustomItem (itemResultID, std::move (comp), std::move (subMenu));
+    addCustomItem (itemResultID, std::move (comp), std::move (subMenu), itemTitle);
 }
 
 void PopupMenu::addSubMenu (String subMenuName, PopupMenu subMenu, bool isActive)
@@ -1932,6 +1993,11 @@ PopupMenu::Options PopupMenu::Options::withTargetScreenArea (Rectangle<int> area
     return with (*this, &Options::targetArea, area);
 }
 
+PopupMenu::Options PopupMenu::Options::withMousePosition() const
+{
+    return withTargetScreenArea (Rectangle<int>{}.withPosition (Desktop::getMousePosition()));
+}
+
 PopupMenu::Options PopupMenu::Options::withDeletionCheck (Component& comp) const
 {
     return with (with (*this, &Options::isWatchingForDeletion, true),
@@ -1982,6 +2048,17 @@ PopupMenu::Options PopupMenu::Options::withInitiallySelectedItem (int idOfItemTo
 Component* PopupMenu::createWindow (const Options& options,
                                     ApplicationCommandManager** managerOfChosenCommand) const
 {
+   #if JUCE_WINDOWS
+    const auto scope = [&]() -> std::unique_ptr<ScopedThreadDPIAwarenessSetter>
+    {
+        if (auto* target = options.getTargetComponent())
+            if (auto* handle = target->getWindowHandle())
+                return std::make_unique<ScopedThreadDPIAwarenessSetter> (handle);
+
+        return nullptr;
+    }();
+   #endif
+
     return items.isEmpty() ? nullptr
                            : new HelperClasses::MenuWindow (*this, nullptr, options,
                                                             ! options.getTargetScreenArea().isEmpty(),
@@ -1991,7 +2068,7 @@ Component* PopupMenu::createWindow (const Options& options,
 
 //==============================================================================
 // This invokes any command manager commands and deletes the menu window when it is dismissed
-struct PopupMenuCompletionCallback  : public ModalComponentManager::Callback
+struct PopupMenuCompletionCallback final : public ModalComponentManager::Callback
 {
     PopupMenuCompletionCallback() = default;
 
@@ -2011,45 +2088,36 @@ struct PopupMenuCompletionCallback  : public ModalComponentManager::Callback
         if (PopupMenuSettings::menuWasHiddenBecauseOfAppChange)
             return;
 
-        auto* focusComponent = getComponentToPassFocusTo();
-
-        const auto focusedIsNotMinimised = [focusComponent]
+        if (auto* focusComponent = Component::getCurrentlyFocusedComponent())
         {
-            if (focusComponent != nullptr)
+            const auto focusedIsNotMinimised = [focusComponent]
+            {
                 if (auto* peer = focusComponent->getPeer())
                     return ! peer->isMinimised();
 
-            return false;
-        }();
+                return false;
+            }();
 
-        if (focusedIsNotMinimised)
-        {
-            if (auto* topLevel = focusComponent->getTopLevelComponent())
-                topLevel->toFront (true);
+            if (focusedIsNotMinimised)
+            {
+                if (auto* topLevel = focusComponent->getTopLevelComponent())
+                    topLevel->toFront (true);
 
-            if (focusComponent->isShowing() && ! focusComponent->hasKeyboardFocus (true))
-                focusComponent->grabKeyboardFocus();
+                if (focusComponent->isShowing() && ! focusComponent->hasKeyboardFocus (true))
+                    focusComponent->grabKeyboardFocus();
+            }
         }
     }
 
-    Component* getComponentToPassFocusTo() const
-    {
-        if (auto* current = Component::getCurrentlyFocusedComponent())
-            return current;
-
-        return prevFocused.get();
-    }
-
     ApplicationCommandManager* managerOfChosenCommand = nullptr;
     std::unique_ptr<Component> component;
-    WeakReference<Component> prevFocused { Component::getCurrentlyFocusedComponent() };
 
     JUCE_DECLARE_NON_COPYABLE (PopupMenuCompletionCallback)
 };
 
 int PopupMenu::showWithOptionalCallback (const Options& options,
                                          ModalComponentManager::Callback* userCallback,
-                                         bool canBeModal)
+                                         [[maybe_unused]] bool canBeModal)
 {
     std::unique_ptr<ModalComponentManager::Callback> userCallbackDeleter (userCallback);
     std::unique_ptr<PopupMenuCompletionCallback> callback (new PopupMenuCompletionCallback());
@@ -2071,7 +2139,6 @@ int PopupMenu::showWithOptionalCallback (const Options& options,
         if (userCallback == nullptr && canBeModal)
             return window->runModalLoop();
        #else
-        ignoreUnused (canBeModal);
         jassert (! (userCallback == nullptr && canBeModal));
        #endif
     }
@@ -2218,15 +2285,13 @@ void PopupMenu::setItem (CustomComponent& c, const Item* itemToUse)
 }
 
 //==============================================================================
+PopupMenu::CustomComponent::CustomComponent() : CustomComponent (true) {}
+
 PopupMenu::CustomComponent::CustomComponent (bool autoTrigger)
     : triggeredAutomatically (autoTrigger)
 {
 }
 
-PopupMenu::CustomComponent::~CustomComponent()
-{
-}
-
 void PopupMenu::CustomComponent::setHighlighted (bool shouldBeHighlighted)
 {
     isHighlighted = shouldBeHighlighted;
