@@ -35,17 +35,17 @@
 
   ID:                 juce_opengl
   vendor:             juce
-  version:            7.0.0
+  version:            7.0.8
   name:               JUCE OpenGL classes
   description:        Classes for rendering OpenGL in a JUCE window.
   website:            http://www.juce.com/juce
   license:            GPL/Commercial
-  minimumCppStandard: 14
+  minimumCppStandard: 17
 
   dependencies:       juce_gui_extra
   OSXFrameworks:      OpenGL
   iOSFrameworks:      OpenGLES
-  linuxLibs:          GL
+  linuxPackages:      gl
   mingwLibs:          opengl32
 
  END_JUCE_MODULE_DECLARATION
